<?php

namespace app\qun\model;

use think\Model;
use app\common\fun\Content AS FContent;

//专题
class Topic extends Model
{
    // 设置当前模型对应的完整数据表名称
    protected $table;// = '__FORM_MODULE__';
    
    //以下三项必须在这里先赋值，不然下面的重新定义table会不生效
    protected $autoWriteTimestamp = false;   // 自动写入时间戳
    protected $dateFormat = 'Y-m-d H:i:s';
    protected $resultSetType = 'array';
    
    protected static $base_table;
    protected static $model_key;
    protected static $table_pre;
    
    //为了调用initialize初始化,生成数据表前缀$model_key
    protected static function scopeInitKey(){}
    protected function initialize()
    {
        parent::initialize();
        preg_match_all('/([_a-z0-9]+)/i',get_called_class(),$array);
        self::$model_key = $array[0][1];
        self::$base_table = $array[0][1].'_content';
        self::$table_pre = config('database.prefix');
        //字段表，带数据表前缀如qb_form_field
        $this->table = self::$table_pre.self::$model_key.'_topic';
    }
    
    public static function get_list($map=[],$order="list desc,id desc",$rows=0,$pages=[]){
        $array = self::where($map)->order($order)->paginate(
            empty($rows)?null:$rows,    //每页显示几条记录
            empty($pages[0])?false:$pages[0],
            empty($pages[1])?['query'=>input('get.')]:$pages[1]
            );
        foreach ($array AS $key=>$rs){
            $info = FContent::info($rs['ext_id'],$rs['ext_sys'],false);
            if ($info) {
                $info['picurl'] && $info['picurl'] = tempdir($info['picurl']);
                $info['url'] = iurl(modules_config($rs['ext_sys'])['keywords'].'/content/show',['id'=>$info['id']]);
                $info['topic'] = getArray($rs);
                $array[$key] = $info;
            }else{
                self::destroy($rs['id']);
                unset($array[$key]);
            }
        }
        return $array;
    }
    
    /**
     * 专题内容入库
     * @param number $qun_id 圈子ID
     * @param number $ext_id 主题ID
     * @param string $ext_sys 主题所在频道ID
     * @return boolean|\app\qun\model\Topic
     */
    public static function add($qun_id=0,$ext_id=0,$ext_sys=''){
        $sysid = is_numeric($ext_sys)?$ext_sys:modules_config($ext_sys)['id'];
        $map = [
            'aid'=>$qun_id,
            'ext_sys'=>$sysid,
            'ext_id'=>$ext_id,
        ];
        if(self::get($map)){
            return true;
        }else{
            $info = FContent::info($ext_id,$ext_sys,false);
            $map['ext_mid'] = intval($info['mid']);
            $result = self::create($map);
            return $result;
        }
    }
    
    /**
     * 删除专题内容
     * @param number $qun_id 圈子ID
     * @param number $ext_id 主题ID
     * @param string $ext_sys 主题所在频道ID
     * @return unknown
     */
    public static function del($qun_id=0,$ext_id=0,$ext_sys=''){
        $sysid = is_numeric($ext_sys)?$ext_sys:modules_config($ext_sys)['id'];
        $map = [
            'aid'=>$qun_id,
            'ext_sys'=>$sysid,
            'ext_id'=>$ext_id,
        ];
        $result = self::where($map)->delete();
        return $result;
    }
    
    /**
     * 给标签调用的
     * @param unknown $tag_array
     * @return unknown
     */
    public static function get_label($tag_array){
        $cfg = unserialize($tag_array['cfg']);
        if (!$cfg['hy_id']) { //个性内容页的情况
            $cfg['hy_id']=input('qid');
        }
        $map = [
            'aid'=>$cfg['aid']?:$cfg['hy_id'],
        ];
        if($cfg['status']){
            $map['status'] = $cfg['status'];
        }
        if($cfg['where']){  //用户自定义的查询语句
            $_array = fun('label@where',$cfg['where'],$cfg);
            if($_array['ext_sys']){
                if(empty($_array['ext_sys'][1])){
                    unset($_array['ext_sys']);
                }elseif (!is_numeric($_array['ext_sys'][1])){
                    $_array['ext_sys'][1] = intval( modules_config($_array['ext_sys'][1])['id'] );
                }
            }
            if($_array['ext_mid'] && empty($_array['ext_mid'][1])){
                unset($_array['ext_mid']);
            }
            
            if($_array){
                $map = array_merge($map,$_array);
            }
        }
        
        if ($cfg['fid']) {
            $map['fid'] = $cfg['fid'];
        }
        
        if (isset($cfg['ext_sys'])) {
            if ($cfg['ext_sys']) {
                $map['ext_sys'] = intval( modules_config($cfg['ext_sys'])['id'] );
            }else{
                unset($map['ext_sys']);
            }
            if ($cfg['ext_mid']) {
                $map['ext_mid'] = $cfg['ext_mid'];
            }else{
                unset($map['ext_mid']);
            }
            if ($cfg['status']) {
                $map['status'] = $cfg['status'];
            }else{
                unset($map['status']);
            }
        }
        
        unset($map['uid']);
        $listdb = static::get_list($map,$order="list desc,id desc",$cfg['rows']);
        foreach($listdb AS $key=>$rs){
            $qinfo = self::get_qun_info($cfg['hy_id']);
            $rs['url'] .= '?style='.$qinfo['style'].'&qid='.$cfg['hy_id'];
            if($rs['uid']!=$qinfo['uid']){
                $rs['url'] .= '&p_uid='.$qinfo['uid'].'&id='.$rs['id'];
            }
            $listdb[$key] = $rs;
        }
        return $listdb;
    }
    
    /**
     * 获取当前圈子的信息
     * @param number $id
     */
    protected static function get_qun_info($id=0){
        static $array;
        if (!$array[$id]) {
            $array[$id] = fun('qun@getbyid',$id);
        }
        return $array[$id];
    }
}
